==> jc-1.4.0.tar.gz: java/awt/geom/Dimension2D.h <==
// public abstract class java.awt.geom.Dimension2D

// class file dependencies
// @dep_class 1db8e8b3f4945eff java_awt_geom_Dimension2D
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_Dimension2D_H_
#define _JC_java_awt_geom_Dimension2D_H_

// Forward structure declarations
struct _jc_java_awt_geom_Dimension2D$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_geom_Dimension2D$sub_refs	_jc_java_awt_geom_Dimension2D$sub_refs;
typedef struct _jc_java_awt_geom_Dimension2D$sub_nonrefs	_jc_java_awt_geom_Dimension2D$sub_nonrefs;
typedef struct _jc_java_awt_geom_Dimension2D$refs	_jc_java_awt_geom_Dimension2D$refs;
typedef struct _jc_java_awt_geom_Dimension2D$nonrefs	_jc_java_awt_geom_Dimension2D$nonrefs;
typedef struct _jc_java_awt_geom_Dimension2D$object	_jc_java_awt_geom_Dimension2D$object;

typedef const struct _jc_java_awt_geom_Dimension2D$vmethods	_jc_java_awt_geom_Dimension2D$vmethods;
typedef const struct _jc_java_awt_geom_Dimension2D$vtable	_jc_java_awt_geom_Dimension2D$vtable;
typedef const struct _jc_java_awt_geom_Dimension2D$vtype	_jc_java_awt_geom_Dimension2D$vtype;

// Constructors
extern void _jc_java_awt_geom_Dimension2D$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_geom_Dimension2D$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *);
extern jdouble _jc_java_awt_geom_Dimension2D$method$getHeight$099466d7bee38f0e(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *);
extern jdouble _jc_java_awt_geom_Dimension2D$method$getWidth$7f6d44448448d217(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *);
extern void _jc_java_awt_geom_Dimension2D$method$setSize$66638f39de03e1be(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *, jdouble, jdouble);
extern void _jc_java_awt_geom_Dimension2D$method$setSize$bc318d5f0fac929e(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *, struct _jc_java_awt_geom_Dimension2D$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Dimension2D$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_awt_geom_Dimension2D$method_info$getHeight$099466d7bee38f0e;
extern _jc_method _jc_java_awt_geom_Dimension2D$method_info$getWidth$7f6d44448448d217;
extern _jc_method _jc_java_awt_geom_Dimension2D$method_info$setSize$66638f39de03e1be;
extern _jc_method _jc_java_awt_geom_Dimension2D$method_info$setSize$bc318d5f0fac929e;

// Virtual methods structure
struct _jc_java_awt_geom_Dimension2D$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *);
	jdouble	(*getHeight$099466d7bee38f0e)(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *);
	jdouble	(*getWidth$7f6d44448448d217)(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *);
	void	(*setSize$66638f39de03e1be)(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *, jdouble, jdouble);
	void	(*setSize$bc318d5f0fac929e)(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *, struct _jc_java_awt_geom_Dimension2D$object *);
};

// Vtable
struct _jc_java_awt_geom_Dimension2D$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Dimension2D$vmethods	java_awt_geom_Dimension2D;
};

// Vtype
struct _jc_java_awt_geom_Dimension2D$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Dimension2D$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Dimension2D$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Dimension2D$refs {
    _jc_java_awt_geom_Dimension2D$sub_refs	java_awt_geom_Dimension2D;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Dimension2D$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Dimension2D$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Dimension2D$sub_nonrefs	java_awt_geom_Dimension2D;
};

// Object instance structure
struct _jc_java_awt_geom_Dimension2D$object {
	_jc_java_awt_geom_Dimension2D$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Dimension2D$vtype	*vtype;
	_jc_java_awt_geom_Dimension2D$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Dimension2D$vtype _jc_java_awt_geom_Dimension2D$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Dimension2D, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Dimension2D$class_object;

#endif	/* _JC_java_awt_geom_Dimension2D_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/Dimension2D.h <==
// public abstract class java.awt.geom.Dimension2D

// class file dependencies
// @dep_class 1db8e8b3f4945eff java_awt_geom_Dimension2D
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_Dimension2D_H_
#define _JC_java_awt_geom_Dimension2D_H_

// Forward structure declarations
struct _jc_java_awt_geom_Dimension2D$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_geom_Dimension2D$sub_refs	_jc_java_awt_geom_Dimension2D$sub_refs;
typedef struct _jc_java_awt_geom_Dimension2D$sub_nonrefs	_jc_java_awt_geom_Dimension2D$sub_nonrefs;
typedef struct _jc_java_awt_geom_Dimension2D$refs	_jc_java_awt_geom_Dimension2D$refs;
typedef struct _jc_java_awt_geom_Dimension2D$nonrefs	_jc_java_awt_geom_Dimension2D$nonrefs;
typedef struct _jc_java_awt_geom_Dimension2D$object	_jc_java_awt_geom_Dimension2D$object;

typedef const struct _jc_java_awt_geom_Dimension2D$vmethods	_jc_java_awt_geom_Dimension2D$vmethods;
typedef const struct _jc_java_awt_geom_Dimension2D$vtable	_jc_java_awt_geom_Dimension2D$vtable;
typedef const struct _jc_java_awt_geom_Dimension2D$vtype	_jc_java_awt_geom_Dimension2D$vtype;

// Constructors
extern void _jc_java_awt_geom_Dimension2D$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_awt_geom_Dimension2D$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Dimension2D$method$getHeight$099466d7bee38f0e(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Dimension2D$method$getWidth$7f6d44448448d217(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Dimension2D$method$setSize$66638f39de03e1be(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *, jdouble, jdouble) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Dimension2D$method$setSize$bc318d5f0fac929e(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *, struct _jc_java_awt_geom_Dimension2D$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Dimension2D$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_awt_geom_Dimension2D$method_info$getHeight$099466d7bee38f0e;
extern _jc_method _jc_java_awt_geom_Dimension2D$method_info$getWidth$7f6d44448448d217;
extern _jc_method _jc_java_awt_geom_Dimension2D$method_info$setSize$66638f39de03e1be;
extern _jc_method _jc_java_awt_geom_Dimension2D$method_info$setSize$bc318d5f0fac929e;

// Virtual methods structure
struct _jc_java_awt_geom_Dimension2D$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *) _JC_JCNI_ATTR;
	jdouble	(*getHeight$099466d7bee38f0e)(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *) _JC_JCNI_ATTR;
	jdouble	(*getWidth$7f6d44448448d217)(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *) _JC_JCNI_ATTR;
	void	(*setSize$66638f39de03e1be)(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *, jdouble, jdouble) _JC_JCNI_ATTR;
	void	(*setSize$bc318d5f0fac929e)(_jc_env *, struct _jc_java_awt_geom_Dimension2D$object *, struct _jc_java_awt_geom_Dimension2D$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_geom_Dimension2D$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Dimension2D$vmethods	java_awt_geom_Dimension2D;
};

// Vtype
struct _jc_java_awt_geom_Dimension2D$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Dimension2D$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Dimension2D$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Dimension2D$refs {
    _jc_java_awt_geom_Dimension2D$sub_refs	java_awt_geom_Dimension2D;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Dimension2D$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Dimension2D$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Dimension2D$sub_nonrefs	java_awt_geom_Dimension2D;
};

// Object instance structure
struct _jc_java_awt_geom_Dimension2D$object {
	_jc_java_awt_geom_Dimension2D$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Dimension2D$vtype	*vtype;
	_jc_java_awt_geom_Dimension2D$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Dimension2D$vtype _jc_java_awt_geom_Dimension2D$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Dimension2D, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Dimension2D$class_object;

#endif	/* _JC_java_awt_geom_Dimension2D_H_ */
